..
    Copyright (C) 2020-2021 CERN.

    Invenio-Vocabularies is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

======================
 Invenio-Vocabularies
======================

.. image:: https://github.com/inveniosoftware/invenio-vocabularies/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-vocabularies/actions?query=workflow%3ACI

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-vocabularies.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-vocabularies

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-vocabularies.svg
        :target: https://github.com/inveniosoftware/invenio-vocabularies/releases

.. image:: https://img.shields.io/pypi/dm/invenio-vocabularies.svg
        :target: https://pypi.python.org/pypi/invenio-vocabularies

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-vocabularies.svg
        :target: https://github.com/inveniosoftware/invenio-vocabularies/blob/master/LICENSE

Invenio module for managing vocabularies, based on Invenio-Records and Invenio-Records-Resources. This module provides:

- Factories for easily generating models, record API classes, services, and resources
- Helpers for importing vocabularies

Further documentation is available on
https://invenio-vocabularies.readthedocs.io/
